# How to invoke a console program in JAVA?

In Java, if you want to invoke a console program and output its parameters or execution results in real-time, you can use the `ProcessBuilder` class. This class allows you to create operating system processes. Here's an example of how to use `ProcessBuilder` to invoke a console program and read its output in real-time:

```java
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Arrays;

public class ConsoleProgramInvoker {

    public static void main(String[] args) {
        // Path to the console program and its arguments
        String programPath = "path/to/your/console/program";
        String[] programArguments = {"arg1", "arg2", "arg3"};

        // Create a ProcessBuilder instance
        ProcessBuilder processBuilder = new ProcessBuilder(programPath, programArguments);

        try {
            // Start the process
            Process process = processBuilder.start();

            // Read the output from the process
            BufferedReader reader = new BufferedReader(new InputStreamReader(process.getInputStream()));
            String line;
            while ((line = reader.readLine()) != null) {
                System.out.println(line);
            }

            // Wait for the process to complete
            int exitCode = process.waitFor();
            System.out.println("Program exited with code: " + exitCode);

        } catch (IOException | InterruptedException e) {
            e.printStackTrace();
        }
    }
}
```

In this example, we create a `ProcessBuilder` instance with the path to the console program and its arguments. We then start the process using `processBuilder.start()`. To read the output from the process in real-time, we create a `BufferedReader` to read from the process's input stream. We read each line of output and print it to the console. Finally, we wait for the process to complete and print its exit code.