# How you can invoke a console program in PHP?

Here's how you can invoke a console program in PHP and output its parameters or execution results in real-time:

```php
<?php

// Path to the console program and its arguments
$cmd = 'path/to/your/console/program';
$args = ['arg1', 'arg2', 'arg3'];

// Construct the full command line
$commandLine = $cmd . ' ' . implode(' ', array_map('escapeshellarg', $args));

// Descriptor specification for defining input/output/error pipes
$descriptorspec = array(
   0 => array("pipe", "r"),  // stdin is a pipe that the child will read from
   1 => array("pipe", "w"),  // stdout is a pipe that the child will write to
   2 => array("pipe", "w")   // stderr is a file to write to
);

// Start the process
$process = proc_open($commandLine, $descriptorspec, $pipes);

if (is_resource($process)) {
    // Close stdin
    fclose($pipes[0]);

    // Read from stdout
    while (!feof($pipes[1])) {
        echo fgets($pipes[1]);
    }

    // Close stdout
    fclose($pipes[1]);

    // Read from stderr
    while (!feof($pipes[2])) {
        echo fgets($pipes[2]);
    }

    // Close stderr
    fclose($pipes[2]);

    // Wait for the process to end
    proc_close($process);
}
?>
```

In this PHP script, we use `proc_open` to start the console program with the specified arguments. We define pipes for stdin, stdout, and stderr, and then we read from the stdout and stderr pipes in real-time, echoing the output to the PHP script's output. Finally, we close the pipes and the process.